#include "stm32f10x.h"
#include "MySSD1963.h"
#include "BoardConfig.h"
#include "Text.h"
#include "Images.h"
/*============================================================================================*/
//Definitions
#define	LED_RADIUS				(TFT_WIDTH/INJECT_NUM)/2.0
#define	ALARM_LED_RADIUS	8
#define	LED_INACTIVE			0xC600//DARK_OLIVE_GREEN
#define	LED_ACTIVE				RED1
#define	ROUNDED						1
#define	NONE							0
#define	OFF								0
#define	ON								1
#define	NUM_INJECTS				28
//Definition of TC parameters' fields names
#define MIN_TEMP					0
#define MAX_TEMP          1
#define MIN_BURN_TEMP     2
#define MAX_BURN_TEMP     3
#define MIN_LEVEL					4
#define MAX_LEVEL 				5
#define MIN_AUTO_SPEED		6
#define MAX_AUTO_SPEED    7
#define INJ_WIDTH   			8
#define VOLUME_RATE 			9
#define G_FREQ_RATE				10
#define PROD_RATE					11
#define MAX_RECEIPT_NUM		16

#define	RNAME							0
#define	UNIT							1
#define	FRATE							2
#define	FWIDTH						3

//Keyboard definitions
#define	RUSSIAN						0
#define	ENGLISH						1
#define	DIGIT							2	

#define	STRING_LENGHT			16

#define	PROCESSING				1
#define NOT_PROCESSING		0	

//Definitions of calibration values' names
	#define		ADC_CODE1_BOX			0
	#define		ADC_CODE2_BOX			1	
	#define		ADC_VALUE1_BOX		2
	#define		ADC_VALUE2_BOX		3	
	#define		DAC1_CODE1_BOX		4
	#define		DAC1_CODE2_BOX		5
	#define		DAC1_VALUE1_BOX		6	
	#define		DAC1_VALUE2_BOX		7	
	#define		DAC2_CODE1_BOX		8
	#define		DAC2_CODE2_BOX		9
	#define		DAC2_VALUE1_BOX		10	
	#define		DAC2_VALUE2_BOX		11	

	#define		SS_FREQ1_BOX			12
	#define		SS_FREQ2_BOX			13
	#define		SS_SPEED1_BOX			14
	#define		SS_SPEED2_BOX			15
#define			CALIB_SENSORS_1	16	

	#define		TS_CUR1_BOX				16
	#define		TS_CUR2_BOX				17
	#define		TS_TEMP1_BOX			18
	#define		TS_TEMP2_BOX			19
	#define		PS_CUR1_BOX				20
	#define		PS_CUR2_BOX				21
	#define		PS_SPEED1_BOX			22
	#define		PS_SPEED2_BOX			23
	#define		PP_CUR1_BOX				24
	#define		PP_CUR2_BOX				25
	#define		PP_PRES1_BOX			26
	#define		PP_PRES2_BOX			27
	#define		LS3_CUR1_BOX			28
	#define		LS3_CUR2_BOX			29
	#define		LS3_LEVEL1_BOX		30
	#define		LS3_LEVEL2_BOX		31	

#define			CALIB_SENSORS_2 32	
	
	#define		LS1_CUR1_BOX		32
	#define		LS1_CUR2_BOX		33
	#define		LS1_PRES1_BOX		34
	#define		LS1_PRES2_BOX		35
	#define		LS1_LEVEL1_BOX	36	
	#define		LS1_LEVEL2_BOX	37
	#define		LS2_CUR1_BOX		38
	#define		LS2_CUR2_BOX		39
	#define		LS2_PRES1_BOX		40
	#define		LS2_PRES2_BOX		41
	#define		LS2_LEVEL1_BOX	42
	#define		LS2_LEVEL2_BOX	43	

#define			CALIB_SENSORS_3 44

	#define		PC_VOL1_BOX			44
	#define		PC_VOL2_BOX			45
	#define		PC_VOL3_BOX			46
	#define		PC_VOL4_BOX			47
	#define		PC_VOL5_BOX			48
	#define		PC_FREQ1_BOX		49	
	#define		PC_FREQ2_BOX		50	
	#define		PC_FREQ3_BOX		51
	#define		PC_FREQ4_BOX		52
	#define		PC_FREQ5_BOX		53
	#define		PC_PROD1_BOX		54
	#define		PC_PROD2_BOX		55
	#define		PC_PROD3_BOX		56
	#define		PC_PROD4_BOX		57
	#define		PC_PROD5_BOX		58
#define			CALIB_SENSORS_4 59



#define			CONTROL_PAGE		0
#define			CONFIG_PAGE			1
#define			CALIBRATE_PAGE1	2
#define			CALIBRATE_PAGE2	3
#define			CALIBRATE_PAGE3	4
#define			CALIBRATE_PAGE4	5
#define			CALIBRATE_PAGE5	6
#define			SETTINGS_PAGE		7
#define			ADDITIONAL_PAGE	8

/*============================================================================================*/
/*Component data*/
typedef	struct
{
	uint16_t		x;
	uint16_t		y;
	float		 		R;
	uint16_t 		color;
	uint8_t*		Caption;
	uint16_t		CaptionWdth;
	uint16_t  	CaptionColor;
}CIRCLE;

typedef	struct
{
	uint16_t	x;
	uint16_t	y;
	uint16_t 	width;
	uint16_t 	height;
	uint8_t 	shape;//rounded angels or not
	uint8_t		lineWidth;
	uint16_t 	color;
}RECTANGLE;

typedef struct
{
	uint16_t x;
	uint16_t y;
	uint16_t width;
	uint16_t height;
	uint16_t Color;
	uint8_t* Caption;
	uint16_t CaptionWdth;
	uint16_t CaptionColor;
  uint8_t* Image;	
	FONTTYPE* Font;	
}BUTTON;
typedef	struct
{
	uint8_t* 	Caption;
	uint16_t	CaptionWdth;
	uint16_t	x;//text coordinates
	uint16_t	y;
	uint8_t*	Value;
	uint16_t 	color;
	FONTTYPE*	CaptionFont;
	FONTTYPE*	ValueFont;
}LABEL;


typedef struct
{
	uint16_t 	x;
	uint16_t 	y;
	uint16_t  width;
	uint16_t  height;
	uint16_t 	Color;
	uint32_t* img;
	uint8_t*  Caption;
	uint8_t*	Pos1Caption;
	uint8_t*  Pos2Caption;
	uint16_t  CaptionColor;
	FONTTYPE*	CaptionFont;
	uint8_t		State;
}
TUMBLER;

typedef struct
{
	uint16_t x;
	uint16_t y;
	uint16_t R;
	uint16_t Color;	
	uint16_t TrueColor;
	uint8_t  State;
	uint8_t* Caption;
	uint16_t CaptionColor;
	FONTTYPE* CaptionFont;	
	uint8_t  CaptionWdth;
}
RADIO_BUTTON;

typedef	struct
{
	uint16_t 	x;
	uint16_t  width;
	uint16_t 	Color;
	uint8_t*  Caption;
	uint16_t  CaptionColor;
	FONTTYPE*	CaptionFont;
}PAGE_MARK;

typedef struct
{
	PAGE_MARK	ControlPages[5];
	uint16_t 	y;
	uint16_t  height;
	uint8_t		ActivePage;
}
PAGE_CONTROL;
typedef struct
{
	uint16_t 	x;
	uint16_t 	y;
	uint16_t  width;
	uint16_t  height;
	uint8_t   lineWdth;
	uint16_t  LineColor;
	uint16_t 	Color;
	uint8_t*  Caption;
	uint16_t  CaptionColor;
	FONTTYPE*	CaptionFont;
	uint8_t* 	Value;
	uint16_t  ValueColor;
	FONTTYPE*	ValueFont;
	uint8_t 	ItemIndex;
}
EDIT_BOX;

typedef struct
{
	uint16_t 	x;
	uint16_t 	y;
	uint16_t  width;
	uint16_t  height;
	uint8_t   lineWdth;
	uint16_t  LineColor;
	uint16_t 	Color;
	uint8_t*  Caption;
	uint16_t  CaptionColor;
	FONTTYPE*	CaptionFont;
	uint16_t 	Value;
	uint16_t  ValueColor;
	FONTTYPE*	ValueFont;
	uint16_t 	MinValue;
	uint16_t  MaxValue;
}
INCDEC_EDIT_BOX;


typedef struct
{
	EDIT_BOX	RName;
	EDIT_BOX	Material;
	EDIT_BOX	Unit;
	EDIT_BOX  FRate;
	EDIT_BOX  FWidth;
	CIRCLE		RInjectLeds[28];
	uint32_t  RInjectConfig;
	uint8_t   ItemIndex;
}
RECEIPT;
/*============================================================================================*/
/*Touch Zones*/
typedef	struct
{
	uint16_t	x1;
	uint16_t	x2;
	uint16_t	y1;
	uint16_t	y2;
}TOUCH_ZONE;
/*============================================================================================*/
/*Interface pages data*/
typedef struct
{
	uint16_t 			Xstart;
	uint16_t 			Ystart;	
	uint16_t 			pageWidth;
	uint16_t 			pageHeight;	
	uint16_t 			BackColor;
	RECTANGLE 		MessageBox;
	CIRCLE				InjectLeds[INJECT_NUM];
	CIRCLE				AlarmLeds	[ALARM_NUM];	
	LABEL					AlarmMessage;
	LABEL					PumpSpeed;
	LABEL					AutoSpeed;
	LABEL					Time;
	LABEL					Distance;
	LABEL					Square;
	LABEL					FillingWidth;
	LABEL					FillingRate;
	LABEL					Temperature;
	LABEL					CurrentVolume;
	LABEL					FilledVolume;
	BUTTON				ModeButton;
INCDEC_EDIT_BOX PumpSpeedControl;
	TUMBLER   		HeatingTmb;
	TUMBLER   		BackBitumTmb;
	RADIO_BUTTON  InjectTmb[5];
}PAGE_1;

typedef struct
{
uint16_t			Xstart;
uint16_t			Ystart;
uint16_t      pageWidth;
uint16_t			pageHeight;
uint16_t			BackColor;
EDIT_BOX			TCParams[12];	
RECEIPT				ReceiptBox;	
RADIO_BUTTON  RInjectTmb[5];
LABEL					RecLabel;
BUTTON				SaveTCButton;	
BUTTON				SetRecButton;
BUTTON				SaveRecButton;	
BUTTON				DelRecButton;	
BUTTON				DelAllRecButton;		
}
PAGE_2;

typedef struct
{
	uint16_t			Xstart;
	uint16_t			Ystart;
	uint16_t      pageWidth;
	uint16_t			pageHeight;
	uint16_t			BackColor;
	EDIT_BOX	CalibSensors[59];
	LABEL					Label1[4];
	BUTTON		CalibrateButton;
	BUTTON		NextButton;
}
PAGE_3;

typedef struct
{
	uint16_t	Xstart;
	uint16_t	Ystart;
	uint16_t  pageWidth;
	uint16_t	pageHeight;
	uint16_t	BackColor;
	LABEL			Label2[4];
	BUTTON*		CalibrateButton;
	BUTTON		PrevButton;
	BUTTON		NextButton;
}
PAGE_4;

typedef struct
{
	uint16_t			Xstart;
	uint16_t			Ystart;
	uint16_t      pageWidth;
	uint16_t			pageHeight;
	uint16_t			BackColor;
	LABEL					Label3[2];
	BUTTON*				CalibrateButton;
	BUTTON				PrevButton;
	BUTTON				NextButton;
}
PAGE_5;
typedef struct
{
	uint16_t			Xstart;
	uint16_t			Ystart;
	uint16_t      pageWidth;
	uint16_t			pageHeight;
	uint16_t			BackColor;
	LABEL					Label4[3];
	BUTTON*				CalibrateButton;
	BUTTON				PrevButton;
}
PAGE_6;

typedef struct
{
	uint16_t			Xstart;
	uint16_t			Ystart;
	uint16_t      pageWidth;
	uint16_t			pageHeight;
	uint16_t			BackColor;
	LABEL					SettingsLabels[3];
	EDIT_BOX			SettingsBoxes[5];
	BUTTON				SaveSetButton;
}
PAGE_7;

typedef struct
{
	uint16_t x;
	uint16_t y;
	uint16_t width;
	uint16_t height;
	uint16_t Color;
	uint8_t*	CaptionString;
	uint16_t CaptionColor;
	FONTTYPE*	CaptionFont;
	uint8_t*	KeyNames[5];
	uint8_t		Type;
	uint8_t*	RetVal;		
	uint8_t		State;
}
KEYBOARD;

extern	PAGE_CONTROL	PageControl;
extern	PAGE_1				ControlPage;
extern  PAGE_2				ConfigPage;
extern	PAGE_3				CalibrationPage1;
extern	PAGE_4				CalibrationPage2;
extern	PAGE_5				CalibrationPage3;
extern	PAGE_6				CalibrationPage4;
extern	PAGE_7				AdditionalPage;
extern  uint32_t			TumblerImgOn[31];
extern  uint32_t  		TumblerImgOff[31];
//extern  uint8_t   		HandButtonImg[145];
//extern  uint8_t				Hand[130];
extern	uint8_t				SetSignImg[128];
extern	uint8_t				SaveSignImg[128];
extern	uint8_t				DelSignImg[128];
extern	uint8_t				DelAllSignImg[128];
extern 	KEYBOARD			Keyboard;
extern	uint8_t 			*ADCModes[2];
extern	uint8_t 			*ADCCng[4];
extern	uint8_t 			*DACCng[7];
extern	uint8_t			 	*SSTypes[5];
extern	uint8_t 			*MaterialTypes[2];
extern	uint8_t				*UnitTypes[2];
extern	uint8_t 			IncImg[8];
extern	uint8_t 			DecImg[8];	
/*============================================================================================*/
void	TFT_DrawButton			(BUTTON* Button);
void	InitPageControl			(PAGE_CONTROL* PageControl);
void	InitControlPage			(void);
void	ShowLed							(CIRCLE* Led);
void	ShowInjectLeds			(CIRCLE* Leds);
void	ShowAlarmLeds				(void);
void	ShowLabel						(LABEL* Label, uint16_t BackColor);
void	ShowTumbler					(TUMBLER* Tmb, uint16_t backcolor);
void	ShowPageControl 		(void);
void	ShowRadioBtn				(RADIO_BUTTON* RBtn, uint16_t backcolor);
void	ShowControlPage			(void);
void	InitConfigPage			(void);
void  ShowEditBox					(EDIT_BOX* EBox);
void	ShowIncDecEditBox		(INCDEC_EDIT_BOX* IDEBox);
void	ShowConfigPage			(void);
void	InitCalibrationPages(void);
void	ShowCalibrationPage1(void);
void	ShowCalibrationPage2(void);
void	ShowCalibrationPage3(void);
void	ShowCalibrationPage4(void);
void	InitAdditionalPage	(void);
void	ShowAdditionalPage	(void);
void	KeyboardInit				(void);
void	ShowKeyboard				(void);
void	ShowPage						(void);
void	UpdateInjects				(uint32_t InjectCng, CIRCLE* Injects);
void	SwitchButton				(BUTTON* Btn,uint8_t condition,uint8_t* str1, uint8_t* str2);
void	UpdateControlParams		(void);
void	LoadDisplayParameters	(void);	//load middle params to display data
void	AlarmMsgShow					(void);














